// SPDX-FileCopyrightText: 2019 - 2026 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

//#include "test_scheduletypeeditdlg.h"

//test_scheduletypeeditdlg::test_scheduletypeeditdlg()
//{

//}

//TEST_F(test_scheduletypeeditdlg, slotEditTextChanged_001)
//{
//    mWidget->m_typeText = "123";
//    mWidget->slotEditTextChanged("21212312312315456489512315489456123165489456123135485");
//    EXPECT_EQ(mWidget->m_lineEdit->text(), "123");
//}

//TEST_F(test_scheduletypeeditdlg, slotEditTextChanged_002)
//{
//    mWidget->m_typeText = "123";
//    mWidget->slotEditTextChanged("");
//    EXPECT_FALSE(mWidget->getButton(1)->isEnabled());
//}

//TEST_F(test_scheduletypeeditdlg, slotEditTextChanged_003)
//{
//    mWidget->m_typeText = "123";
//    mWidget->slotEditTextChanged("   ");
//    EXPECT_FALSE(mWidget->getButton(1)->isEnabled());
//}

//TEST_F(test_scheduletypeeditdlg, slotFocusChanged_001)
//{
//    mWidget->m_lineEdit->setText("");
//    mWidget->slotFocusChanged(false);
//}

//TEST_F(test_scheduletypeeditdlg, slotBtnCancel_001)
//{
//    mWidget->slotBtnCancel();
//}

//TEST_F(test_scheduletypeeditdlg, slotBtnNext_001)
//{
//    mWidget->slotBtnNext();
//}
